AdaptyPaywallProduct class
- Annotations
Properties
- accessLevelId → String
-
The identifier of the access level configured by you in Adapty Dashboard.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
A Boolean value that indicates whether the product is available for family sharing in App Store Connect. (Will be
falsefor iOS version below 14.0 and macOS version below 11.0).final - localizedDescription → String
-
A description of the product.
final
- localizedTitle → String
-
The name of the product.
final
- paywallABTestName → String
-
Same as
abTestNameproperty of the parent AdaptyPaywall.final - paywallName → String
-
Same as
nameproperty of the parent AdaptyPaywall.final - paywallProductIndex → int
-
The index of the product in the paywall.
final
- paywallVariationId → String
-
Same as
variationIdproperty of the parent AdaptyPaywall.final - price → AdaptyPrice
-
The object which represents the main price for the product.
final
- productType → String
-
The type of the product.
final
- regionCode → String?
-
The region code of the locale used to format the price of the product.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- subscription → AdaptyProductSubscription?
-
Detailed information about subscription (intro, offers, etc.)
final
- vendorProductId → String
-
Unique identifier of a product from App Store Connect or Google Play Console.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited