AdaptyRemoteConfig class

Annotations

Properties

data String
final
dictionary Map<String, dynamic>?
A custom dictionary configured in Adapty Dashboard for this paywall (same as data)
no setter
hashCode int
The hash code for this object.
no setterinherited
locale String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited